####################
Line Measurer (LiMe)
####################

This library provides a set of tools to fit emission lines from ionized spectra. Its design aims for a simple usage in both
a single line and Big Data observations. The emission labeling supports a multi-gaussian component fitting.
The measurements can be stored in several formats to facilitate the posterior analysis of the gas chemistry and kinematics.

Please check the `online documentation <https://lime-stable.readthedocs.io/>`_.

Installation
============

The library can be installed directly from its pip_ project page running the command:

``pip install lime-stable``

Development
===========

LiMe is currently in a beta release. Please check its github_ for the latest version news and tutorials.
Any comment/issue/request can be added as an issue on the github_ page.

.. _pip: https://pypi.org/project/lime-stable/
.. _github: https://github.com/Vital-Fernandez/lime

